"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.genBlockSchema = void 0;
const toycode_core_1 = require("@qlin/toycode-core");
const config_1 = require("../config");
const utils_1 = require("../utils");
const componentMap_1 = require("../componentMap");
const searchAction_1 = require("./searchAction");
const modal_1 = require("./modal");
const useModal_1 = require("./useModal");
const shared_1 = require("./shared");
const table_1 = require("./table");
const form_1 = require("./form");
const index_1 = require("../genCommonCode/index");
// REFACTOR 抽离 search form 相关代码到独立的文件
function genSearchForm(params) {
    const form = {
        componentName: 'FForm',
        props: {
            layout: 'inline',
        },
        children: [],
    };
    for (const item of params) {
        const comp = (0, componentMap_1.componentMap)(item.component.componentName);
        const formCompProps = {
            ...item.component.props,
            ...comp.props,
        };
        let children;
        if (item.mappingId) {
            if (item.component.appendAll) {
                formCompProps.options = {
                    type: toycode_core_1.ExtensionType.JSExpression,
                    value: `appendAll(${item.mappingId})`,
                };
            }
            else {
                formCompProps.options = {
                    type: toycode_core_1.ExtensionType.JSExpression,
                    value: item.mappingId,
                };
            }
        }
        else if (item.options?.length) {
            children = (0, shared_1.handleComponentOptions)(item.options, comp.subName);
            if (item.component.appendAll) {
                children.unshift({
                    componentName: comp.subName,
                    props: {
                        label: '全部',
                        value: null,
                    },
                });
            }
        }
        else if (item.apiSchema) {
            formCompProps.options = {
                type: toycode_core_1.ExtensionType.JSExpression,
                value: (0, utils_1.genOptionsName)(item.name),
            };
            if (item.component.appendAll) {
                children = [
                    {
                        componentName: comp.subName,
                        props: {
                            label: '全部',
                            value: null,
                        },
                    },
                ];
            }
        }
        form.children.push({
            componentName: 'FFormItem',
            props: {
                label: item.title,
            },
            children: [
                {
                    componentName: comp.name,
                    props: formCompProps,
                    directives: {
                        'v-model': `searchParams.${item.name}`,
                    },
                    children,
                },
            ],
        });
    }
    return form;
}
function genTemplate(apiSchema) {
    const children = [];
    if (apiSchema.params?.length) {
        children.push(genSearchForm(apiSchema.params));
    }
    return [...children, ...(0, table_1.genTableTemplate)(apiSchema)];
}
function genBlockMeta(meta) {
    if (!(0, utils_1.isGenComponent)(meta)) {
        const importSources = [
            {
                imported: 'defineRouteMeta',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes',
            },
        ];
        return {
            importSources,
            content: `
            defineRouteMeta({
                name: '${(0, utils_1.genSFCFileName)(meta.name)}',
                ${meta.title ? `title: '${meta.title}',` : ''}
            });
            `,
        };
    }
}
function genSearchFormSetupCode(ctx, params) {
    const importSources = [
        ...(0, form_1.genFormImportResources)(ctx, params),
        ...genAppendAllCode(ctx, params),
        {
            imported: 'reactive',
            type: toycode_core_1.ImportType.ImportSpecifier,
            source: 'vue',
        },
    ];
    const fetchCode = (0, form_1.genFetchCode)(ctx, params);
    return {
        importSources: importSources.concat(fetchCode.importSources),
        content: `
        const searchParams = reactive({
            ...initSearchParams
        });
        ${fetchCode.content}
        `,
    };
}
function genAppendAllCode(ctx, fields) {
    const importSources = [];
    if (fields.find((item) => item.component.appendAll &&
        (item.mappingId || item.options?.length))) {
        importSources.push({
            imported: 'appendAll',
            type: toycode_core_1.ImportType.ImportSpecifier,
            source: ctx.getUtilsFilePathImp(),
        });
    }
    return importSources;
}
function genInitSearchParams(params) {
    let content = '';
    if (params.length) {
        const fields = params.map((item) => {
            return `${item.name}: null`;
        });
        content = `
        const initSearchParams = {
            ${fields.join(', ')}
        }
        `;
    }
    return {
        importSources: [],
        content,
    };
}
function genSetupCode(ctx, pageConfig) {
    const queryApiSchema = pageConfig.apiSchema;
    const setupCodes = [
        genInitSearchParams(queryApiSchema.params),
        (0, table_1.genTableSetupCode)(ctx, queryApiSchema, {
            hasRefresh: !!(queryApiSchema.params.length || pageConfig.relationModals.length),
        }),
    ];
    if (queryApiSchema.params.length) {
        setupCodes.push(genSearchFormSetupCode(ctx, queryApiSchema.params));
    }
    setupCodes.push(genBlockMeta(pageConfig.meta));
    return setupCodes.filter(Boolean);
}
function genBlockSchema(ctx, pageConfig) {
    pageConfig.apiSchema.params = (0, shared_1.formReqData)(pageConfig.apiSchema.params || []);
    pageConfig.apiSchema.resData.fields = (0, shared_1.formatResData)(pageConfig.apiSchema.resData.fields);
    const initSFC = {
        componentName: 'SFCComponent',
        ...(0, utils_1.genDirAndFileName)(ctx, pageConfig),
        setupCodes: genSetupCode(ctx, pageConfig),
        children: [
            {
                componentName: 'div',
                props: {
                    class: 'common-page',
                },
                children: genTemplate(pageConfig.apiSchema),
            },
        ],
    };
    const sfc = [searchAction_1.applySearchAction, useModal_1.applyModal].reduce((acc, action) => {
        return action(ctx, pageConfig, acc);
    }, initSFC);
    return {
        componentsTree: [sfc, ...(0, modal_1.genRelationModals)(ctx, pageConfig)],
        css: config_1.defaultPageCss,
        jsCodes: (0, index_1.getCommonJsCode)(ctx),
        dependencies: ctx.dependence.getPackages(),
    };
}
exports.genBlockSchema = genBlockSchema;
