"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatResData = exports.formReqData = exports.genImportedMappingCode = exports.insertActionInTable = exports.insertActionInSearchForm = exports.mergeCodeSnippets = exports.genLabelWidth = exports.findComponent = exports.getDefaultValue = exports.handleComponentOptions = void 0;
// 跟具体库和平台无关的共享代码
const lodash_1 = require("lodash");
const toycode_core_1 = require("@qlin/toycode-core");
function handleComponentOptions(options, componentName) {
    return options.map((option) => {
        return {
            componentName,
            props: {
                label: option.label,
                value: option.value,
            },
        };
    });
}
exports.handleComponentOptions = handleComponentOptions;
function getDefaultValue(field) {
    if ((0, lodash_1.isEmpty)(field.component.defaultValue)) {
        if (field.type === 'string') {
            return '""';
        }
        return 'null';
    }
    return field.component.defaultValue;
}
exports.getDefaultValue = getDefaultValue;
function findComponent(components, id) {
    const result = components.find((component) => {
        return component.id === id;
    });
    if (result)
        return result;
    return findComponent(components.reduce((acc, cur) => {
        if (cur.children && cur.children.length) {
            return acc.concat(cur.children);
        }
        return acc;
    }, []), id);
}
exports.findComponent = findComponent;
function genLabelWidth(fields) {
    let charNum = 4;
    fields.forEach((field) => {
        if (field.title?.length > charNum) {
            charNum = field.title.length;
        }
    });
    const extraWidth = fields.find((field) => field.component.required) ? 8 : 0;
    return charNum * 16 + extraWidth;
}
exports.genLabelWidth = genLabelWidth;
function mergeCodeSnippets(codeSnippets) {
    return codeSnippets.reduce((acc, cur) => {
        acc.setupCodes.push(cur.setup);
        if (cur.component.parentId) {
            const targetComponent = findComponent(acc.children, cur.component.parentId);
            targetComponent.children.push(cur.component);
        }
        else {
            acc.children.push(cur.component);
        }
        return acc;
    }, {
        children: [],
        setupCodes: [],
    });
}
exports.mergeCodeSnippets = mergeCodeSnippets;
function findSearchForm(components) {
    for (const component of components) {
        if (component.componentName === 'FForm') {
            return component;
        }
    }
    return findSearchForm(components.reduce((acc, cur) => {
        if (cur.children) {
            acc = acc.concat(cur.children);
        }
        return acc;
    }, []));
}
function insertActionInSearchForm(components, actionComponent) {
    const searchForm = findSearchForm(components);
    const actionFormItem = searchForm.children[searchForm.children.length - 1];
    if (!actionFormItem.props?.label) {
        actionFormItem.children.unshift(actionComponent);
    }
    else {
        searchForm.children.push({
            componentName: 'FFormItem',
            children: [actionComponent],
        });
    }
}
exports.insertActionInSearchForm = insertActionInSearchForm;
function findTable(components) {
    for (const component of components) {
        if (component.componentName === 'FTable') {
            return component;
        }
    }
    return findTable(components.reduce((acc, cur) => {
        if (cur.children) {
            acc = acc.concat(cur.children);
        }
        return acc;
    }, []));
}
function insertActionInTable(components, actionComponent) {
    const tableComponent = findTable(components);
    const tableActionColumn = tableComponent.children.find((comp) => {
        return comp.props?.label === '操作';
    });
    if (tableActionColumn) {
        tableActionColumn.children.push(actionComponent);
    }
    else {
        tableComponent.children.push({
            componentName: 'FTableColumn',
            props: {
                align: 'center',
                label: '操作',
            },
            directives: {
                'v-slot': '{ row }',
            },
            children: [actionComponent],
        });
    }
}
exports.insertActionInTable = insertActionInTable;
function genImportedMappingCode(ctx, fields) {
    const importSources = [];
    fields.forEach((item) => {
        if (item.mappingId) {
            importSources.push({
                imported: item.mappingId,
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getConstantsFilePathImp(),
            });
        }
    });
    return importSources;
}
exports.genImportedMappingCode = genImportedMappingCode;
function formReqData(fields) {
    return fields.filter((item) => item.checked);
}
exports.formReqData = formReqData;
function formatResData(fields) {
    return fields
        .map((item) => {
        if (item.mappingId) {
            return {
                alias: `${item.name}Text`,
                ...item,
            };
        }
        if (item.name.endsWith('Time')) {
            return {
                alias: `${item.name}Text`,
                ...item,
            };
        }
        return item;
    })
        .filter((item) => item.checked);
}
exports.formatResData = formatResData;
