"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyModal = exports.applySwitchStatusModal = exports.applyDeleteModal = exports.applyViewModal = exports.applyUpdateModal = exports.applyAddModal = void 0;
const toycode_core_1 = require("@qlin/toycode-core");
const shared_1 = require("./shared");
const constants_1 = require("../constants");
function applyAddModal(ctx, sfc) {
    sfc.setupCodes.push({
        importSources: [
            {
                imported: 'AddModal',
                type: toycode_core_1.ImportType.ImportDefaultSpecifier,
                source: './components/addModal.vue',
            },
            {
                imported: 'useAddModal',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getUseModalImp(),
            },
            {
                imported: 'FButton',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
            {
                imported: 'PlusOutlined',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design/icon',
            },
        ],
        content: `
        const addModal = useAddModal();
        `,
    });
    sfc.children.push({
        componentName: 'AddModal',
        props: {
            onSuccess: {
                value: '() => refresh()',
                type: toycode_core_1.ExtensionType.JSExpression,
            },
        },
        directives: {
            'v-model:visible': 'addModal.state.visible',
        },
    });
    const actionComponent = {
        componentName: 'FButton',
        props: {
            type: 'primary',
        },
        events: {
            click: 'addModal.show',
        },
        children: ['新增'],
        slots: [
            {
                name: 'icon',
                component: {
                    componentName: 'PlusOutlined',
                },
            },
        ],
    };
    (0, shared_1.insertActionInSearchForm)(sfc.children, actionComponent);
    return sfc;
}
exports.applyAddModal = applyAddModal;
function applyUpdateModal(ctx, sfc) {
    sfc.setupCodes.push({
        importSources: [
            {
                imported: 'UpdateModal',
                type: toycode_core_1.ImportType.ImportDefaultSpecifier,
                source: './components/updateModal.vue',
            },
            {
                imported: 'useCommonModal',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getUseModalImp(),
            },
            {
                imported: 'FButton',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
        ],
        content: `
        const updateModal = useCommonModal();
        `,
    });
    sfc.children.push({
        componentName: 'UpdateModal',
        props: {
            [constants_1.ROW_DATA_PROP_NAME]: {
                value: 'updateModal.state.rowData',
                type: toycode_core_1.ExtensionType.JSExpression,
            },
            onSuccess: {
                value: 'refresh',
                type: toycode_core_1.ExtensionType.JSExpression,
            },
        },
        directives: {
            'v-model:visible': 'updateModal.state.visible',
        },
    });
    const actionComponent = {
        componentName: 'FButton',
        props: {
            type: 'link',
        },
        events: {
            click: 'updateModal.show(row)',
        },
        children: ['编辑'],
    };
    (0, shared_1.insertActionInTable)(sfc.children, actionComponent);
    return sfc;
}
exports.applyUpdateModal = applyUpdateModal;
function applyViewModal(ctx, modal, sfc) {
    sfc.setupCodes.push({
        importSources: [
            {
                imported: 'ViewModal',
                type: toycode_core_1.ImportType.ImportDefaultSpecifier,
                source: './components/viewModal.vue',
            },
            {
                imported: 'useCommonModal',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getUseModalImp(),
            },
            {
                imported: 'FButton',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
        ],
        content: `
        const viewModal = useCommonModal();
        `,
    });
    sfc.children.push({
        componentName: 'ViewModal',
        props: {
            [constants_1.ROW_DATA_PROP_NAME]: {
                value: 'viewModal.state.rowData',
                type: toycode_core_1.ExtensionType.JSExpression,
            },
        },
        directives: {
            'v-model:visible': 'viewModal.state.visible',
        },
    });
    const actionComponent = {
        componentName: 'FButton',
        props: {
            type: 'link',
        },
        events: {
            click: 'viewModal.show(row)',
        },
        children: ['查看'],
    };
    (0, shared_1.insertActionInTable)(sfc.children, actionComponent);
    return sfc;
}
exports.applyViewModal = applyViewModal;
function applyDeleteModal(modal, sfc) {
    sfc.setupCodes.push({
        importSources: [
            {
                imported: 'request',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes',
            },
            {
                imported: 'FTooltip',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
            {
                imported: 'FButton',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
            {
                imported: 'FMessage',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
        ],
        content: `
        const confirmDelete = async (row) => {
            await request('${modal.apiSchema.url}', row);
            FMessage.success('删除成功');
            refresh();
        };
        `,
    });
    const actionComponent = {
        componentName: 'FTooltip',
        props: {
            mode: 'confirm',
        },
        events: {
            ok: 'confirmDelete(row)',
        },
        children: [
            {
                componentName: 'FButton',
                props: {
                    type: 'link',
                },
                children: ['删除'],
            },
        ],
        slots: [
            {
                name: 'title',
                component: {
                    componentName: 'div',
                    children: [modal.title || '确认删除当前内容？'],
                },
            },
        ],
    };
    (0, shared_1.insertActionInTable)(sfc.children, actionComponent);
    return sfc;
}
exports.applyDeleteModal = applyDeleteModal;
function applySwitchStatusModal(ctx, modal, sfc) {
    const targetField = modal.apiSchema.params[0];
    const functionName = `change${targetField.name[0].toUpperCase() + targetField.name.slice(1)}`;
    sfc.setupCodes.push({
        importSources: [
            {
                imported: 'request',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes',
            },
            {
                imported: 'FTooltip',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
            {
                imported: 'FButton',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
            {
                imported: 'FMessage',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: '@fesjs/fes-design',
            },
            {
                imported: 'findAnotherValue',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getUtilsFilePathImp(),
            },
            {
                imported: 'findAnotherLabel',
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getUtilsFilePathImp(),
            },
            {
                imported: targetField.mappingId,
                type: toycode_core_1.ImportType.ImportSpecifier,
                source: ctx.getConstantsFilePath(),
            },
        ],
        content: `
        const ${functionName} = async (row) => {
            await request('${modal.apiSchema.url}', {
                ${targetField.name}: findAnotherValue(${targetField.mappingId}, row.${targetField.name})
            });
            FMessage.success('修改成功');
            refresh();
        };
        `,
    });
    const actionComponent = {
        componentName: 'FTooltip',
        props: {
            mode: 'confirm',
        },
        events: {
            ok: `${functionName}(row)`,
        },
        children: [
            {
                componentName: 'FButton',
                props: {
                    type: 'link',
                },
                children: [
                    `设置为 {{ findAnotherLabel(row.${targetField.name}) }}`,
                ],
            },
        ],
        slots: [
            {
                name: 'title',
                component: {
                    componentName: 'div',
                    children: [
                        modal.title ||
                            `确认设置为 {{ findAnotherLabel(row.${targetField.name}) }}？`,
                    ],
                },
            },
        ],
    };
    (0, shared_1.insertActionInTable)(sfc.children, actionComponent);
    return sfc;
}
exports.applySwitchStatusModal = applySwitchStatusModal;
function applyModal(ctx, pageConfig, sfc) {
    pageConfig.relationModals.forEach((modal) => {
        if (modal.type === 'add') {
            applyAddModal(ctx, sfc);
        }
        else if (modal.type === 'update') {
            applyUpdateModal(ctx, sfc);
        }
        else if (modal.type === 'delete') {
            applyDeleteModal(modal, sfc);
        }
        else if (modal.type === 'switchStatus') {
            applySwitchStatusModal(ctx, modal, sfc);
        }
        else if (modal.type === 'view') {
            applyViewModal(ctx, modal, sfc);
        }
    });
    return sfc;
}
exports.applyModal = applyModal;
