"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPageField = exports.getDataField = exports.genDirAndFileName = exports.isGenComponent = exports.genModalDir = exports.genOutputDir = exports.genFileNameByPath = exports.hasModal = exports.genSFCFileName = exports.genFetchName = exports.genOptionsName = exports.genComponentName = exports.isReactiveSearch = exports.isPaginationField = void 0;
const lodash_1 = require("lodash");
function isPaginationField(field) {
    return ['pagination', 'page', 'pager', 'pageInfo', 'pageinfo'].includes(field);
}
exports.isPaginationField = isPaginationField;
function isReactiveSearch(params) {
    return params.length <= 3;
}
exports.isReactiveSearch = isReactiveSearch;
function genComponentName(fileName) {
    return fileName.replace(/( |^)[a-z]/g, (L) => L.toUpperCase());
}
exports.genComponentName = genComponentName;
function genOptionsName(fieldName) {
    return `${genFetchName(fieldName)}List`;
}
exports.genOptionsName = genOptionsName;
function genFetchName(fieldName) {
    const result = (0, lodash_1.words)(fieldName);
    if (/id/i.test(result[result.length - 1]) && result.length > 1) {
        return result.slice(0, result.length - 1).join('');
    }
    return result.join('');
}
exports.genFetchName = genFetchName;
function genSFCFileName(fileName) {
    return (0, lodash_1.camelCase)(fileName);
}
exports.genSFCFileName = genSFCFileName;
function hasModal(pageConfig) {
    return pageConfig.relationModals?.length > 0;
}
exports.hasModal = hasModal;
function genFileNameByPath(apiPath) {
    const splitResult = apiPath.split('/').slice(-2).join('_');
    return (0, lodash_1.camelCase)(splitResult);
}
exports.genFileNameByPath = genFileNameByPath;
function genOutputDir(ctx, blockConfig) {
    if (blockConfig.meta.outputDir) {
        return blockConfig.meta.outputDir;
    }
    return isGenComponent(blockConfig.meta)
        ? ctx.getComponentsDir()
        : ctx.getPagesDir();
}
exports.genOutputDir = genOutputDir;
function genModalDir(ctx, blockConfig) {
    if (!hasModal(blockConfig)) {
        return '';
    }
    const outputDir = genOutputDir(ctx, blockConfig);
    const fileName = genSFCFileName(blockConfig.meta.name);
    return `${outputDir}/${fileName}/components`;
}
exports.genModalDir = genModalDir;
function isGenComponent(meta) {
    return meta.type.endsWith('Component');
}
exports.isGenComponent = isGenComponent;
function genDirAndFileName(ctx, blockConfig) {
    const fileName = genSFCFileName(blockConfig.meta.name);
    const outputDir = genOutputDir(ctx, blockConfig);
    if (!hasModal(blockConfig)) {
        return {
            dir: outputDir,
            fileName: `${fileName}.vue`,
        };
    }
    return {
        dir: `${outputDir}/${fileName}`,
        fileName: 'index.vue',
    };
}
exports.genDirAndFileName = genDirAndFileName;
// TODO pick 支持数组
function getDataField(apiSchema) {
    const dataField = apiSchema.resData.pick[0];
    if (!dataField || dataField === 'cycle')
        return null;
    return dataField;
}
exports.getDataField = getDataField;
// TODO pick 支持数组
function getPageField(apiSchema) {
    if (!apiSchema.pagination)
        return null;
    const pageField = apiSchema.pagination.pick[0];
    if (!pageField || pageField === 'page')
        return null;
    return pageField;
}
exports.getPageField = getPageField;
